@@ -61,7 +61,11 @@ def download(url, filename = None, root = CACHE_PATH):
     if os.path.exists(download_target) and not os.path.isfile(download_target):
         raise RuntimeError(f"{download_target} exists and is not a regular file")
 
-    if deepspeed_utils.using_deepspeed and not deepspeed_utils.is_local_root_worker() and not os.path.isfile(download_target):
+    if (
+            deepspeed_utils.using_deepspeed
+            and not deepspeed_utils.is_local_root_worker()
+            and not os.path.isfile(download_target)
+    ):
         # If the file doesn't exist yet, wait until it's downloaded by the root worker.
         deepspeed_utils.local_barrier()
 
